@@ -278,7 +278,7 @@ def _create_datam(app, cls, module, name, _type, obj, lines=None):
     args = []
     try:
         if _type in [METHOD, FUNCTION]:
-            argspec = inspect.getargspec(obj) # noqa
+            argspec = inspect.getfullargspec(obj) # noqa
             for arg in argspec.args:
                 args.append({'id': arg})
             if argspec.defaults:
@@ -289,8 +289,8 @@ def _create_datam(app, cls, module, name, _type, obj, lines=None):
                     # Match the defaults with the count
                     if 'object at 0x' not in str(default):
                         args[len(args) - cut_count + count]['defaultValue'] = str(default)
-    except Exception:
-        print("Can't get argspec for {}: {}".format(type(obj), name))
+    except Exception as e:
+        print("Can't get argspec for {}: {}. Exception: {}".format(type(obj), name, e))
 
     if name in app.env.docfx_signature_funcs_methods:
         sig = app.env.docfx_signature_funcs_methods[name]
@@ -632,6 +632,11 @@ def build_finished(app, exception):
                     if merged_params:
                         obj['syntax']['parameters'] = merged_params
 
+                    if 'parameters' in obj['syntax'] and obj['type'] == 'method':
+                        for args in obj['syntax']['parameters']:
+                            if 'defaultValue' not in args:
+                                args['isRequired'] = True
+
                     # Raise up summary
                     if 'summary' in obj['syntax'] and obj['syntax']['summary']:
                         obj['summary'] = obj['syntax'].pop('summary').strip(" \n\r\r")
@@ -687,6 +692,9 @@ def build_finished(app, exception):
                 if obj['type'] == 'module':
                     convert_module_to_package_if_needed(obj)
 
+                if obj['type'] == 'method':
+                    obj['namewithoutparameters'] = obj['source']['id']
+
                 # To distinguish distribution package and import package
                 if obj.get('type', '') == 'package' and obj.get('kind', '') != 'distribution':
                     obj['kind'] = 'import'
@@ -741,7 +749,8 @@ def build_finished(app, exception):
                 found_node = find_node_in_toc_tree(toc_yaml, parent_level)
 
                 if found_node:
-                    found_node.setdefault('items', []).append({'name': uid, 'uid': uid})
+                    found_node.pop('uid', 'No uid found')
+                    found_node.setdefault('items', [{'name': 'Overview', 'uid': parent_level}]).append({'name': uid, 'uid': uid})
                 else:
                     toc_yaml.append({'name': uid, 'uid': uid})
 
@@ -756,9 +765,8 @@ def build_finished(app, exception):
         writable.write(
             dump(
                 [{
-                    'uid': 'project-' + app.config.project,
                     'name': app.config.project,
-                    'items': toc_yaml
+                    'items': [{'name': 'Overview', 'uid': 'project-' + app.config.project}] + toc_yaml
                 }],
                 default_flow_style=False,
             )
@@ -768,9 +776,9 @@ def build_finished(app, exception):
     index_children = []
     index_references = []
     for item in toc_yaml:
-        index_children.append(item.get('uid', ''))
+        index_children.append(item.get('name', ''))
         index_references.append({
-            'uid': item.get('uid', ''),
+            'uid': item.get('name', ''),
             'name': item.get('name', ''),
             'fullname': item.get('name', ''),
             'isExternal': False
@@ -815,7 +823,7 @@ def missing_reference(app, env, node, contnode):
                 fields = (module, reftarget)
             else:
                 fields = (module, node['py:class'], reftarget)
-            reftarget = '.'.join(fields)
+            reftarget = '.'.join(field for field in fields if field is not None)
 
         return make_refnode(app.builder, refdoc, reftarget, '', contnode)
 
